## Phenomenology and natural history

### Tic suppression

Since tic suppression is part of the treatment protocol for the Comprehensive Behavioral Intervention for Tics (CBIT) and for Exposure and Response Prevention, there has been increased interest in investigating the characteristics of tic suppression and the factors that affect it.   A study of 26 TS adolescents compared free ticcing with a tic suppression condition \citep{25786675}.  During the free ticcing condition, tic distribution across body locations was consistent with the view that most tics occur at the level of the shoulders and above: eye tics were the most frequent, followed by facial/cervical tics, and those involving the arms and legs.  Tics involving the trunk were the least common.  During the tic suppression condition, eye tics increased in 10 subjects, as did hand tics in 3 subjects. Tic suppression was most successful for tics in body locations generally associated with fewer tics, such as the legs and trunk. The authors suggest that tic suppression involves specific, rather than global, inhibition since some types of tics are easier to suppress than others. Historically, other categories have been used to classify tics, such as simple vs. complex tics and motor vs. phonic tics.  The results of this study suggest that future research may benefit from including body location in tic analyses. 

By definition, children with Tourette syndrome (TS) have had tics for over a year. They can often suppress their tics briefly and they do so more effectively when rewarded for successful suppression. It has not been known whether the ability to suppress tics develops only with practice over the years of having tics or whether the ability to suppress tics is present when tics initially occur.  Greene and colleagues addressed this question in children whose tics had developed within the past few months \citep{Greene_2015_NTsuppress}. When children received tokens with monetary value for tic-free intervals, they had significantly more of these intervals compared to a baseline, unrewarded condition. This result suggests the possibility that behavior therapy for tics may work, at least for some children, even before TS can be diagnosed. 

Most tic patients frequently try to suppress tics, but find suppressing them uncomfortable and distracting. However, those who are more satisfied with their ability to suppress their tics also report a higher quality of life \citep{26360257}.

### Sensory phenomena 

Premonitory urges are common in TS, are perceived as triggers for tics, and are as bothersome as the tics themselves to many people with TS.  Premonitory urges have a sensory component and many TS patients also report sensory sensitivities. Researchers have been clarifying the nature of premonitory urges and attempting to determine the underlying causes of the sensory sensitivities.

Scores on the Premonitory Urge for Tics Scale (PUTS) and the University of São Paulo Sensory Phenomena Scale (USP-SPS) were significantly correlated with total tic severity, tic complexity and vocal tic scores in youth and adults with TS \citep{Kano_2015}. The PUTS and USP-SPS scores were also correlated with scores on the Dimensional Yale-Brown Obsessive-Compulsive Scale. This study provides additional evidence that the association between premonitory urges and tics is complex and may be influenced by obsessive-compulsive tendencies. 

Another study examined the association between premonitory urges and interoceptive awareness \citep{25879819}. Interoceptive awareness was measured by how well subjects were able to mentally track their heartbeats, without being able to take their own pulse, during a specific period of time.  Interoceptive awareness, tic severity, and obsessive-compulsive symptom severity were used in a multiple regression to predict PUTS scores.  Greater interoceptive awareness and tic severity were significantly associated with higher PUTS scores while OCD symptom severity was not.  The authors suggest that high interoceptive awareness may lead people to set a low threshold for perception of their own internal physiological sensations and therefore cause them to interpret these sensations as an urge to tic. Interestingly, TS subjects had lower interoceptive awareness than controls, suggesting that this downregulation of interoception might reflect a compensatory process.

### Symptoms and comorbidity

Recent research has again demonstrated the wide prevalence of TS-associated comorbities and is a reminder of the need to perform studies with large enough sample sizes to examine the effects of comorbidities on the dependent variables of interest.

A retrospective review of 1,000,000 people in the Taiwan National Health Insurance Research Database examined the association between epilepsy and TS \citep{26597416}.  1,062 children and adolescents with TS were matched on age and sex with a control group of 3,186 subjects.  The TS group had an 18-fold increased risk of epilepsy compared to the control group; the risk was still elevated 16-fold after adjusting for comorbidities (_i.e._, bipolar disorder, depression, learning difficulties, autism, anxiety disorders, sleep disorders). The authors acknowledge the possibility that some tics may have been mistaken for seizures, given the nature of the data set, but these data do suggest an important hypothesis for future confirmation. 

In a large study of psychiatric comorbidity in TS, approximately 800 families were recruited primarily from TS specialty clinics in four different countries over a 16-year period \citep{25671412}. A total of 1374 participants with TS and 1142 family members unaffected by TS were included.  86% of the TS participants had at least one psychiatric comorbidity and 72% had either OCD or ADHD.  Mood, anxiety and disruptive behavior disorders each occurred in approximately 30% of the TS participants. The genetic correlations between TS and mood were accounted for by ADHD and OCD, while ADHD alone accounted for the genetic correlations of TS with anxiety and disruptive behavior disorders.

A study of 400 patients seen at a TS specialty clinic found that 39% had coprolalia and 20% had copropraxia \citep{26089672}. When the 222 patients with full comorbidity data were examined, only 13.5% had "pure" TS (_i.e._, without comorbidities). None  of the "pure" TS group had coprolalia and none had a family history of obsessive-compulsive disorder. 

Emotional regulation difficulties were described in three studies, reminding us that for many TS patients, tics are not their most problematic symptoms. Greater irritability was seen in TS adults with more severe tics and those with comorbid ADHD \citep{25716486}. Eddy et al. found that both male and female TS subjects, compared to controls, reported more distress during emotionally intense situations and rated their abilities to take other people's perspectives lower \citep{26144583}. An experienced clinician who has done research on "rage attacks" in TS has provided a clinically useful summary of current knowledge regarding aggressive symptoms in TS, OCD, ADHD and mood disorders, and described treatment options \citep{Budman_2015}. Given that emotional regulation difficulties are frequently associated with greater tic severity, improving emotional modulation skills may be an appropriate target of psychological interventions. 

More research is also being conducted on personality differences associated with TS. A small study of 17 male adolescents \citep{26078419} found that the only significant difference between the TS subjects and 51 age- and gender-matched controls on the Minnesota Multiphasic Personality Inventory-Adolescent version was that the TS subjects scored higher on the Obsessiveness Content Scale.  In contrast, a study of 50 TS adults in Germany used a variety of instruments to measure psychological symptoms and personality traits \citep{26112450}. Comorbidities were common (41% OCD, 28% depression, 26% ADHD). Patients with OCD had more severe tics and there was a trend for those with ADHD to have more severe tics. Only 29% of the patients had no pathological personality traits, measured with the Inventory of Clinical Personality Accentuations. The demand-anxious trait was the most common personality trait seen in patients and was present in 39%, while histrionic personality traits were not found in any patients. Personality traits in patients with "pure" TS (_i.e._, without comorbid ADHD, OCD or depression) were comparable to those of the control group. Interestingly, ADHD did not contribute to increased probability of pathological personality traits. Although quality of life was affected by both personality traits and comorbidities, personality traits had a larger impact on quality of life. 

### Course

More research is being conducted on the developmental progression of tics and other symptoms in TS.  This work may provide clues that help clarify what factors contribute to the appearance and disappearance of transient tics and what factors explain the disappearance or amelioration of tics as children with TS enter adulthood.

One study examined home videos recorded in the first 6 months of life from 34 children who were exhibiting autistic behaviors in their second year of life \citep{26246137}. Families reported that development during the first year of life had been normal. Videos of 18 boys were examined in detail. The primary focus of the study was on autism, though 11 of the 18 subjects were later diagnosed with TS. The nearly ubiquitous availability of home baby videos in some cultures suggests that a similar pseudo-prospective study design could be used to identify behavioral features predicting later development of TS.

The clinical characteristics of children who developed TS before the age of 4 were compared with those whose tics developed at age 6 or older \citep{26596364}.  The younger group had a higher rate of speech dysfluencies (_e.g._, stuttering) and oppositional defiant disorder. There was no difference between the two groups in prevalence of ADHD or obsessive-compulsive symptoms.  Interestingly, the children in the early-onset group were more likely to have mothers with tics.  The authors attributed this to mothers with tics being more likely to recognize tics in their children. The authors also suggest that prenatal or perinatal maternal environmental factors may contribute to the development of tics.  An alternative explanation may relate to the fact that TS is much less common in girls than in boys.  Consequently, tics in a woman may represent a higher genetic load, resulting in a more severe form of tics and an earlier age of onset in her children.

Researchers re-evaluated 75 patients previously seen at a University-based TS clinic after a mean follow-up of 9 years \citep{25193042}.  Reported TS impairment was more likely to decrease over time in males and increase in females.  In addition, women were more likely than men to have an expansion in adulthood of the number of body regions exhibiting tics, primarily in the upper extremities. This result suggests that sex continues to influence TS symptoms beyond adolescence. 
