
### Pharmacological studies

GABA involvement was studied in 23 TS children, aged 8-12, and 67 controls using a battery of vibrotactile tasks with a subset of the children (19 with TS, 25 controls) also undergoing GABA-edited magnetic resonance spectroscopy (MRS) \citep{26041822}. Lower GABA concentration in the right sensorimotor cortex correlated with greater motor tic severity (\(r=-0.55\)).  There were no significant differences between groups on reaction time and baseline amplitude discrimination threshold.  However, TS children showed impaired tactile adaptation. The authors suggest that MRS GABA and tactile measures might useful as biomarkers of treatment response.

Positron emission tomography (PET) was used to investigate striatal D2/D3 dopamine receptor availability in TS subjects and controls using a D2/D3 receptor antagonist ( \([^{11}C]\)raclopride) and an agonist with preferential binding to D3Rs (\([^{11}C]\)(+)PHNO) \citep{25788222}. No differences were found for these 3 regions when the TS subjects were compared with the controls, and there were no significant correlations between receptor availability and tic severity. The authors conclude that their results challenge the widely held view that striatal dopamine receptors have a fundamental role in TS pathophysiology, though they acknowledge that endogenous dopamine levels may have influenced the results since these radiotracers are displaceable by physiological synaptic concentrations of dopamine. 

Two studies examined dopamine D1 and D2-like receptors in healthy adults, measuring D1R and D2R availability during stop-signal and continuous performance tasks \citep{25878272}. Stop-signal reaction time was negatively correlated with both D1R and D2R receptor availability in the the associative and sensory motor regions of the striatum.  In contrast, neither D1R nor D2R receptor availability was associated with performance on the continuous performance task, suggesting that stop-signal and continuous performance tasks are associated with different neurochemical mechanisms related to motor response inhibition.  In a study of healthy adults, learning from positive outcomes was positively correlated with D1R binding in the putamen and caudate while there was an inverted U-shaped relationship ( \(r^2=0.19\) ) between learning from negative outcomes and D2R binding in the putamen \citep{25562824}. A dietary manipulation that reduced dopamine precursor levels significantly improved learning from negative outcomes. These results were interpreted as providing evidence that dopamine acts as a reward prediction error signal rather than as a saliency signal.

A detailed review focuses on histaminergic modulation of striatal function its possible role in TS \citep{26275849}. The authors suggest that, during wakefulness and increased attention, histaminergic neurons will be more active with the result that the striatum will be more responsive to thalamostriatal input and and feed-forward inhibition will dominate. Several lines of evidence related to the role of histamine in TS were discussed. A family linkage study identified a rare mutation in the gene encoding histidine decarboxylase. HDC transgenic mice exhibit decreased pre-pulse inhibition of startle responses and an increase in a variety of amphetamine-induced stereotypies that were prevented by pretreatment with histamine infusion or use of haloperidol. Reduced histamine production was suggested to produce dopaminergic disregulation of the basal ganglia and sympotoms similar to those seen in TS.

### Clinical and neuropsychological studies

In an intriguing report from a group studying social cognition in TS, TS subjects and controls demonstrated intact mentalizing when observing animated triangles demonstrating simple and complex interactions \citep*{26177119}. However, TS subjects also tended to attribute human-like intentions when two triangles were moving randomly. This tendency was not explained by clinical symptoms or by other constructs such as executive function or alexithymia.

Two studies examined the effects of comorbidities on social and cognitive skills. Social responsiveness and cognitive flexibility were examined in TS children and adolescents \citep{25631951}.  TS subjects were rated as having poorer social motivation and skills, using the Social Responsiveness Scale, compared to age-matched controls. TS subjects also took significantly longer to complete the Trail Making Tests which measure cognitive flexibility and visual motor integration.  However, of the 31 TS subjects, 11 had OCD, 18 had ADHD and 8 had an anxiety disorder.  Once these comorbidities were taken into account, group differences on the Trail Making Tests and the Social Responsiveness Scale were no longer significant.  These findings demonstrate the need for studies to have adequate sample sizes to provide sufficient power to disentangle effects related specifically to tics versus to other symptoms.  Another study was designed to separate effects attributable to OCD \citep{25296570}.  Sustained attention, using a continuous performance test, was examined in 48 children and adolescents who had OCD alone, tic disorders (TD) alone or both OCD and TD.  A high rate of ADHD was seen in all groups (62% of the OCD+TD group, 27% in the TD alone group, and 20% in the OCD alone group). Anxiety was also frequent (77% in the OCD+TD group compared to 49% for the other two groups combined). The OCD+TD group had more errors of omission and higher reaction time variability.  These results of this study provide additional evidence that the OCD+TD phenotype is associated with more severe symptoms including attentional difficulties and symptoms of anxiety. 

Two studies examined motor control.  In a clever analysis of video recordings of the eyes \citep{26175694}, spontaneous blink rate, which is related to dopamine levels, was higher in children with TS than in controls both during task performance and during a rest period. In contrast, pupil diameter, which is related to norepinephrine levels, was correlated with anxiety in TS subjects although not in controls. Researchers also used a cognitive control task to measure ability to properly update current task information, ignore competing information when selecting between response options, and retrieve and use relevant response contingencies. Accuracy on this cognitive control task accounted for half of tic severity variance.  In an unrelated study, TS children, without ADHD or OCD, had significantly greater difficulty maintaining postural stability than did age- and gender-matched controls, especially when subjects had access only to accurate vestibular, rather than visual or somatosensory, cues \citep{25683311}.

Somatosensory sensitivity was compared in adults with "pure" TS and controls by establishing thresholds for externally applied stimuli \cite{26818628}. No differences were found between the two groups supporting the view that the sensory abnormalities seen in TS may be related to abnormal interoceptive awareness or abnormal central sensorimotor processing.  

Three recent studies examined the effects of attention on tic frequency and the results have implications for how treatment protocols could be modified to increase effectiveness. The role of attention on tic frequency was examined under several conditions \citep{25185800}.  Tic frequencies were lower for 12 TS subjects during a baseline condition when they were alone in a room compared to when they were alone in a room looking at themselves in a mirror. A second study was performed to determine whether the increase in frequency was due to increased attention to the tics themselves or due to increased self-awareness in general. In addition to the conditions previously described, 16 subjects were also shown videos of themselves while they were not ticcing.  Tic frequency was again lower during the baseline compared to the mirror condition.  Tic frequency was even lower when subjects were watching the video of themselves while not ticcing.  The authors suggest that future treatments teach patients to attend to states when they experience fewer tics.  Another study of TS adults \citep{25486384} compared tic frequency while subjects were engaged in tasks that involved attending to particular fingers, colored circles, or whether a tic had occurred during a specific 2-second interval. Observations for these tasks were made both during free ticcing and tic suppression.  Not surprisingly, more tics were seen during a baseline free ticcing condition. During the attention tasks, tic frequency was greatest while subjects focused on their tics.  In contrast, tic frequency decreased during the color attention condition and decreased further during the finger attention condition.  When subjects suppressed their tics, they reduced their baseline tic frequency similarly across all attention conditions. The results are consistent with the idea that internally-directed attention, especially with a focus on tics, may contribute to momentary increases in tic severity. The authors suggested that behavioral treatment might be more effective if it focused on teaching patients to focus on external events and voluntary actions when they are in situations that are most likely to result in ticcing.  Anecdotal evidence has suggested that tics decrease when people are involved in musical activity, so Bodeck et al. systematically studied the effects of music \citep{Bodeck_2015}.  Questionnaires completed by 29 patients supported the idea that listening to music and performing music decrease tic frequency. TS subjects were then observed in a variety of conditions.  Tics were almost completely eliminated when subjects were performing music. Listening to music and mental imagery of musical performance also resulted in decreases in tic frequency. The authors suggested that focused attention, along with fine motor control and goal-directed behavior, produced the decrease in tics.

The stereotyped nature of tics has led some to suggest that the neural systems involved in habitual behavior may also be associated with tic generation.  A complex, three-stage instrumental learning paradigm was used to compare medicated and unmedicated TS adults with a control group to determine whether they differed in goal-directed _vs._ habitual behavior \citep{26490329}. During the first stage, subjects learned to associate six different stimuli with six specific outcome pictures and a specific response (i.e., left or right key press).  During the second stage, subjects were presented with two outcomes with an indication that one outcome was devalued (i.e., no longer associated with point rewards) and subjects had to press the key associated with the outcome that would still generate points. During the third stage (_i.e._, "slip-of-action" stage), the six outcomes were presented simultaneously with indications that two outcomes were devalued so that responding to the associated stimuli would no longer generate points. Subjects were instructed to press the key associated with stimuli associated with the still valued outcomes (i.e., "Go") and withhold the response (i.e., "No-Go") for stimuli associated with devalued outcomes. This task determined whether excessive "slips of action" were related to outcome devaluation insensitivity. A control Go/No-Go task, with devaluing of cueing stimuli, was used to measure to measure response rates where high rates on this task would indicate working memory deficits or deficient response inhibition.  There were no group performance differences for the first two stages of the instrumental learning task or on the baseline Go/No-Go task. However, unmedicated patients showed a significantly higher response rate to devalued outcomes compared to controls (in Bonferroni-corrected _post hoc_ analyses), while there was no difference between medicated subjects and controls.  In addition, tic severity in unmedicated subjects was correlated with response rates to devalued outcomes and with stronger structural connectivity between the right supplementary motor cortex and the posterior putamen.  The results obtained in this study contrasted with results on similar tasks obtained with subjects with obsessive-compulsive disorder without tics.  The authors argued that over-reliance on habits in OCD without tics is associated with impaired knowledge of response-outcome associations, while this type of learning was intact in both TS groups in this study. They concluded that habit formation is enhanced in unmedicated TS subjects but medication may normalize responses. 
