## Pathophysiology  

### Pathological studies

An important study follows up on the autopsy results from the Vaccarino lab by comparing RNA transcripts from the basal ganglia of 9 TS and 9 matched control subjects \citep{25199956}. The most strongly associated set of downregulated transcripts involved striatal interneurons, consistent with the autopsy studies. The leading set of upregulated transcripts involved immune-related genes even though none of the TS subjects met proposed diagnostic criteria for PANDAS or PANS. The results obtained in the present study using brain tissue did not overlap with those of previous studies using blood samples. The authors interpret their results as implicating disrupted basal ganglia interneuron signaling in the pathophysiology of severe TS.

### Animal models

Rodent and monkey tic models have been developed in order to study the mechanisms involved in tic generation more directly and a number of studies using rodent models were published in 2015.  Removing about half of the cholinergic interneurons in the dorsolateral striatum produced increased fragmented grooming behavior in response to repeated unpredictable acoustic startle stimuli in mice and also increased repetitive sniffing in response to D-amphetamine challenge \citep{25561540}.  Ablation in the dorsomedial striatum did not produce similar deficits. None of the experimental conditions produced a change in prepulse inhibition. These results provide partial support for the autopsy data linking some characteristic TS symptoms to cholinergic interneuron deficits in the dorsolateral striatum.

A rat model was used to determine to what extent cortical and striatal input affected the temporal and spatial properties of motor tics \citep*{26674861}.  Focal blockade of GABA-A receptors with bicuculline injections into the anterior striatal motor region produced focal tic-like movements of the forelimbs. Medium spiny neurons (MSNs) and fast spiking interneurons (FSIs) exhibited increased activity during these movements, and all of the MSNs were only active during them.  All of the FSIs were active during tics, but a minority followed this increase in activity by a decrease.  Four different patterns were seen in globus pallidus (GP) neurons.  About half of the GP neurons demonstrated increased activity during the tic-like movements, while the rest showed only inhibition or a combination of inhibition and excitation. The effects of cortical input were studied using short bursts of high-frequency electrical pulses applied at random intervals to the region of primary motor cortex representing the forelimb. Stimulation was provided before and after the bicuculline injections. The results suggested that the precise timing of tic occurrence was related to both incoming excitatory cortical input and the delay since the previous tic. These results support the fundamental involvement of the corticostriatal network with tic occurrence.

The role of GABA in tic generation was also studied in adult mice by injecting the GABA-A antagonist picrotoxin into areas throughout the cortex and striatum \citep{25597650}.  Infusions into the central and dorsolateral striatum produced tic-like movements of the front paw, hind paw or head. Infusions into the dorsomedial striatum did not have a significant behavioral effect.  Infusion into the ventral striatum produced increased locomotor activation in addition to sterotypical sniffing and wall licking without other tic-like movements. Infusions into the sensorimotor cortex produced tic-like movements in addition to increased behavioral activation involving cage exploration, sniffing, and occasional licking. When an NMDA receptor antagonist was infused into the dorsolateral striatum prior to infusing picrotoxin into the same location, tic frequency decreased significantly, thus demonstrating the role of glutamatergic activity in tic generation.  Infusion of a GABA-A agonist into the sensorimotor cortex prior to picrotoxin infusion in the dorsolateral striatum also resulted in significant tic suppression. EEG recordings ruled out seizure activity. The authors summarize these results as providing evidence that these tic-like movements require cortico-striatal interactions, with a key role for glutatmateric afferents, rather than autonomous striatal activity.

In a genetically engineered mouse model of TS+OCD  ("Ticcy" D1CT-7 transgenic mice) \citep{26453289}, a small population of dopamine D1 receptor-expressing (D1+) somatosensory cortical and limbic neurons is chronically potentiated, resulting in cortical and amygdalar glutamatergic excitation of striatothalamic, striatopallidal and nigrostriatal subcircuits.  Tics were decreased by the use of drugs that acted at different points in this "hyperglutamergic cortico/amygdalo-striato-thalamo-cortical [CSTC] circuit".  Excitatory forebrain serotonin and norepinephrine activity was blocked by ritanserin (a serotonin 2a/2c antagonist) and prazosin (an \( \alpha_{1} \) adrenergic antagonist) respectively. In contrast, downstream striatothalamic neurons' glutamate-triggered GABA output and downstream nigrostriatal neurons' glutamate-triggered co-modulatory dopamine output were blocked by moxonidine (an agmatine/imidazoline-1 agonist) and bromocriptine (a D2 dopamine agonist) respectively. All four of these drugs decreased tic frequency and were considered to be "circuit-breakers" for the hyperglutamatergic CSTC circuit, thus supporting an important role of glutamate in generating the abnormal tic-like movements seen in these mice. 

### Neuroimaging studies

The challenges of using neuroimaging techniques to study pediatric and clinical subjects are described in detail along with suggestions concerning various strategies that can be used to collect higher quality data \citep{26754461}. The profound effects of even very small head movements on structural MRI analyses were identified in a well-designed study \citep{25498430}. T1-weighted MRI of brain was acquired in 12 healthy adults while they were still or engaged in specific types of movement including nodding, head shaking or a movement each subject invented and then repeated during the scan run. Even during scans when subjects attempted to remain still, there was an average of 3 mm/min of accumulated motion measured using RMSpm (root mean square displacement per minute). During the motion conditions, substantial impact was found on gray matter volume and thickness estimates. Apparent volume loss averaged approximately 0.7% mm/min of subject motion.  The greatest reductions in gray matter occurred in pre- and post-central cortex and in the temporal lobes. Motion-associated increases in thickness were seen in some frontal regions and deep sulci such as the medial orbital frontal region. Significant effects due to motion were still present even after excluding scans that failed a rigorous quality control procedure. Recommendations included reducing head motion during scans as much as possible, controlling for motion in statistical analyses, and using correlational analyses to determine the associations between head motion and the predictors of interest. Tisdall and colleagues described a method to limit the effects of movement artifacts by using a motion tracking system to provide prospective motion correction during scanning \citep{26654788}. 

A whole-brain analysis of cortical gray matter found reduced gray matter (GM) thickness in the insula and sensorimotor cortex for TS children and young adults compared to a matched control group \citep{26538289}. GM thickness in these areas correlated negatively with Premonitory Urge for Tics Scale scores. 

Resting-state functional magnetic resonance imaging identified greater functional connectivity between the right dorsal anterior insula (dAI) and the bilateral supplementary motor area (SMA) in TS adults compared to controls \citep{25855089}.  Post-hoc analyses found significant correlations between PUTS scores and connectivity between right dAI and right SMA2 and between right dAI and left SMA1. These regions may be involved in the increased awareness of body sensations that tend to be associated with premonitory urges. The authors paid attention to head movement and removed high-movement frames. However, recent analyses suggest that the motion threshold of 0.4mm used in this analysis, and the choice not to regress global signal, may not adequately remove artifactual correlations between brain regions due to residual small head movements during the scan \citep{25462692}. 

A review examined TS task-based fMRI studies in TS including studies of tic suppression, voluntary motor execution, voluntary motor inhibition, and tic severity \citep{26402403}. Free ticcing conditions (four studies) most commonly activated the left cerebellum, right cingulum, left middle frontal gyrus, the Rolandic operculum, right pallidum, right SMA and thalamus. In motor response inhibition studies, on No-Go trials TS subjects exhibited greater activation in the bilateral prefrontal cortex, thalamus and caudate.  In contrast, on voluntary motor execution tasks greater activation in TS subjects was seen in the left prefrontal cortex, right cingulum, and the anterior SMA. Tic severity ratings were correlated with greater activation of the right dorsal premotor cortex and the SMA.  Anterior cingulate cortex and SMA were involved across task types.  The thalamus was involved in all types of studies except for self-produced movements. The authors also briefly summarize the the many issues related to neuroimaging studies such as the associated comorbidities, medication effects, the need for longitudinal studies, and the confounding effect of tics during scanning. 
Additional studies are noted in Table 1.

