
## Treatment

### Psychotherapy

2015 saw several practical advances in the psychotherapeutic treatments available for tics. [TicHelper.com](http://www.tichelper.com/) is a commercial adaptation of Comprehensive Behavioral Intervention for Tics (CBIT) to the Internet, discussed at the [London congress in 2015](http://www.webcitation.org/6gWlBTYcC) \citep{Himle:TicHelper:London}. It is potentially an important treatment option, especially for the many TS patients who do not live near a behavior therapist. Efficacy testing is ongoing (see [the trial summary at ClinicalTrials.gov](https://www.clinicaltrials.gov/ct2/show/NCT02413216)). 

McGuire et al. dug into the data from 2 previously reported, pivotal, randomized controlled CBIT studies that together enrolled over 200 children and adults \citep{25988365}. The superior treatment benefit from CBIT, compared to a control therapy, could be attributed to differential improvement in only a few types of tics, including throat clearing, sniffing, and complex tics. In general, vocal tics were more likely to improve following CBIT treatment. The controlled breathing used as a competing response for vocal tics may have allowed patients to direct attention away from the associated premonitory urges in a way that muscle-tensing competing responses for motor tics did not. This report also extends previous information about premonitory phenomena, including varying prevalence of premonitory urges across specific tic types.

"Living with Tics" is a modularized cognitive-behavioral treatment focused on decreasing tic-related impairment and improving quality of life.  This treatment program was recently tested in a randomized, wait-list control study, with the active intervention including up to 10 weekly sessions for children and adolescents \citep{25500348}. Treatment modules focused on a variety of themes including self-esteem, emotion regulation, parent training, cognitive restructuring, coping at school, overcoming tic-related avoidance, and 1 or 2 sessions of habit-reversal training.  Active treatment led to improved child-rated quality of life and reduced blinded clinician-rated tic impairment compared to the wait-list control group. An additional 7 wait-listed youth then participated in the treatment program resulting in data on 19 participants for open-trial analyses.  With the larger sample size the reductions in tic severity (i.e., 30%), anxiety, obsessive-compulsive symptoms, and parent-rated impairment were significant.  Both the youth and their parents reported satisfaction with the intervention, serving as a reminder that improving quality of life can be a desired treatment goal.

A small, uncontrolled open trial of mindfulness-based stress reduction treatment was completed in 18 individuals at least 16 years old \citep{25149879}.  Treatment consisted of eight weekly two-hour group classes and one four-hour retreat.  Participants were taught a tic-specific meditation exercise that involved noticing any urges to tic while maintaining a focus on one's breathing rather than trying to change or eliminate the urge to tic. Only one subject dropped out and overall tic severity was decreased by 20% for participants who completed the program.  An independent evaluator rated ten subjects as much improved" or "very much improved" and these subjects were considered treatment responders.  The gains for the fifteen participants who had not had medication changes in the interim were maintained at a one month follow-up visit.

An open-label trial of psychotherapy using a cognitive psychophysiological model of tic behavior was conducted with 102 adults who had TS or chronic tic disorder \citep{26250742}. Ten weeks of individual psychotherapy involved a number of components including increasing tic awareness; improving muscle control; preventing excessive muscle tension; decreasing an overactive action style; identifying low and high risk activities in terms of tic probability; highlighting differences in behaviors, thoughts and feelings related to differences in tic probability; decreasing perfectionistic beliefs linked to tension; generalization; and relapse prevention. These psychotherapy components were chosen because prior research suggested that some people with tics have perfectionist beliefs leading to an "impulsive overactive style" that produces frustration and tension in addition to tics.  Large effect sizes were seen for both patient groups compared to the waiting list control group: 65% of the chronic tic disorder group and 74% of the TS group had reductions of more than 35% on the Tourette Syndrome Global Scale. YGTSS total tic scores were also significantly decreased for both patient groups.  At the end of treatment 78 of 85 completers were rated as having no more than mild symptoms, regardless of the starting severity, while the other 7 were considered to have moderate symptoms.  Large effect sizes were seen for tic subtypes (_i.e._, simple, complex, motor, phonic) and similar results were seen for various tic body locations. The TSGS improvements were maintained in the 52 subjects who completed a 6-month follow-up evaluation.

A follow-up study examined the effects of this psychotherapy approach on event-related potentials and lateralized readiness potentials (LRPs) \citep{26022060}. EEGs were recorded for 20 TS subjects and 20 control subjects matched for age, sex and intelligence while performing a stimulus-response compatibility inhibition task.  During the No-Go condition, the TS group exhibited a delayed and overactivated frontal late positive component on the No-Go portion of the task. The authors considered this frontal activation as evidence of an adaptive mechanism that allowed patients to perform similarly to the control subjects on the task. This difference did not normalize with psychotherapy, consistent with this interpretation.  TS subjects exhibited a larger incorrect activation of the stimulus-locked LRP (sLRP) in addition to larger correct activation of the sLRP and delayed correct activation sLRP onset. Although sLRP onset and rLRP peak normalized after psychotherapy, the larger sLRP amplitude did not. The authors suggest that therapy produced some normalization of activation in the premotor and motor cortex in TS patients. 

### Medication

Efforts to maximize the value of pharmacological treatment continue. Lemmon et al. reported on a carefully designed, thoughtful pilot study of glutamatergic modulators as tic treatment \citep{26002052}. Twenty-three children with TS completed a double-blind, parallel group study involving 6 weeks of placebo, D-serine (up to 30 mg/kg/day) or riluzole (up to 200 mg/day). Total tic scores from the YGTSS improved by 25-38% in each group, without significant group differences. Although power was limited by the small sample size, this null result argues against eager pursuit of glutamatergic medications for TS at this juncture.

A meta-analysis of 22 randomized, controlled trials (RCTs) involving 2,385 children with ADHD found no causal relationship between stimulants and onset of tics \citep{26299294}. Rather, tics were associated with ADHD itself (5.7% in the psychostimulant groups and 6.5% in the placebo groups). This summary of previous evidence hopefully can further reassure patients and prescribers that stimulants do not cause tics. The evidence for this conclusion is strongest for methylphenidate (19 of the 22 trials), and in a large RCT in children with TS and ADHD, tics _improved_ significantly with methylphenidate \citep{11865128}. In the meta-analysis, results were similar for the 3 trials involving amphetamines, but tic severity did increase in 12 adults with TS after a single intravenous dose of 0.3mg/kg D-amphetamine \citep{23876376}.

Four patients with treatment-refractory TS were studied in an early report of results using vigabatrin, a medication from the GABA-aminotransferase inhibitor class \citep{vigabatrinPR}. One patient had a clinically significant reduction in tics while two others had tic reduction of approximately 25% but did not report subjective clinical improvement.

### Neurosurgery

A revised consensus statement on DBS in TS appeared recently \citep{25476818}. It provides an important update to the 2006 recommendations \citep{16991144}, guided by almost a decade of generally positive results from an increasingly varied set of patients, though with limited evidence from randomized allocation treatment studies.  Several major changes were made in the recommendations.  First, the recommendation that DBS patients be 25 years or older has been replaced by a focus on clinical symptoms and severity. However, at a minimum, local ethics committee involvement was recommended for patients under 18 years of age. The second major modification in the guidelines was that a patient have a caregiver who would be available to accompany the patient to frequent follow-up appointments. In addition, the group recommended absence of active suicidal or homicidal ideation for 6 months prior to surgery. The final change in the guidelines recommended identifying and addressing personality disorders, malingering, factitious symptoms, embellishment, and other factors that can substantially complicate assessment or treatment.  

Fourteen patients were randomly allocated to DBS on-stimulation or off-stimulation conditions for the first 3 months after DBS leads were placed in the GPi (globus pallidus, pars interna), followed by a switch to the other condition for another 3 months \citep{25882029}. Ratings were collected blind to stimulation status, and 13 patients completed assessments during both conditions. Total YGTSS scores were 15% lower at the end of the on-stimulation period compared with the off-stimulation period (p=0.048). Three serious adverse events occurred: two infections in the DBS hardware and one episode of hypomania. Further improvements were seen during the long-term open label treatment period.  This study is important as it provides evidence of efficacy of stimulation _per se_ from a study with random assignment to initial condition. 

A case study raised the issue of temporary DBS treatment in a patient with TS and ADHD treated with thalamic DBS from ages 17-23 \citep{26290773}. This case raises important questions discussed in the consensus statement \citep{25476818}, but without adequate controls it is impossible to know whether DBS was the cause of tic improvement.  

### Other treatment

Lisanby and colleagues reported a careful, randomized controlled trial of repetitive transcranial magnetic stimulation (rTMS) aimed at supplementary motor area (SMA) in 20 adults with TS \citep{25912296}. There were suggestions of improvement, but on average, patients in the sham treatment group improved almost as much as those in the active treatment group. However, rTMS most effectively stimulates superficial regions of cortex, and an Israeli group employed a new coil designed to provide deeper stimulation in an open-label study of 12 patients with treatment-refractory TS \citep{25342253}. The patients as a whole did not improve significantly, but a _post hoc_ analysis showed benefit in the 6 patients who also had OCD, and the treatment was well tolerated. A double blind, sham-controlled study in TS patients with OCD will be needed to confirm efficacy.

Cranial electrical stimulation (CES) was used in an open label trial to treat 42 children with TS who were less than 12 years old \citep{25546850}. Patients applied electrodes to their earlobes when they went to bed so that they could receive the treatment on a daily basis for 24 weeks. Treatment sessions lasted 60 minutes and children were allowed to sleep during treatment. Only one child dropped out before the completion of the study. The mean YGTSS score significantly decreased from 26 when they were initially seen to 11 after treatment completion. These results must be viewed as preliminary, since an RCT is required to rule out spontaneous improvement.
 
Another treatment undergoing initial efficacy testing is an oral orthotic device with which some patients have reported success. The rationale and design of the study, and initial safety results, were reported at the London meeting \citep{orthotic:London}, and efficacy testing continues (see [the trial summary at ClinicalTrials.gov](https://clinicaltrials.gov/ct2/show/NCT02067819)). 